antares.apps.obligation.service package
=======================================

Module contents
---------------

.. automodule:: antares.apps.obligation.service
   :members:
   :undoc-members:
   :show-inheritance:
